@@ -1,42 +1,42 @@
 package Bio::Roary::CommandLine::ProteinMuscleAlignmentFromNucleotides;
-$Bio::Roary::CommandLine::ProteinMuscleAlignmentFromNucleotides::VERSION = '3.1.0';
+$Bio::Roary::CommandLine::ProteinMuscleAlignmentFromNucleotides::VERSION = '3.1.1';
 # ABSTRACT: Take in a multifasta file of nucleotides, convert to proteins and align with muscle
 
 
 use Moose;
 use Getopt::Long qw(GetOptionsFromArray);
+use File::Copy;
 use Bio::Roary::AnnotateGroups;
 use Bio::Roary::External::Prank;
 use Bio::Roary::Output::GroupsMultifastaProtein;
 use Bio::Roary::SortFasta;
 extends 'Bio::Roary::CommandLine::Common';
 
-
 has 'args'        => ( is => 'ro', isa => 'ArrayRef', required => 1 );
 has 'script_name' => ( is => 'ro', isa => 'Str',      required => 1 );
 has 'help'        => ( is => 'rw', isa => 'Bool',     default  => 0 );
 
-has 'nucleotide_fasta_files'  => ( is => 'rw', isa => 'ArrayRef' );
-has '_error_message'          => ( is => 'rw', isa => 'Str' );
-has 'verbose'                 => ( is => 'rw', isa => 'Bool', default => 0 );
+has 'nucleotide_fasta_files' => ( is => 'rw', isa => 'ArrayRef' );
+has '_error_message'         => ( is => 'rw', isa => 'Str' );
+has 'verbose'                => ( is => 'rw', isa => 'Bool', default => 0 );
 
 sub BUILD {
     my ($self) = @_;
 
-    my ( $nucleotide_fasta_files, $help,$verbose );
+    my ( $nucleotide_fasta_files, $help, $verbose );
 
     GetOptionsFromArray(
         $self->args,
-		'v|verbose'                 => \$verbose,
-        'h|help'              => \$help,
+        'v|verbose' => \$verbose,
+        'h|help'    => \$help,
     );
-	
+
     if ( defined($verbose) ) {
         $self->verbose($verbose);
         $self->logger->level(10000);
     }
 
-    $self->help($help) if(defined($help));
+    $self->help($help) if ( defined($help) );
     if ( @{ $self->args } == 0 ) {
         $self->_error_message("Error: You need to provide at least 1 FASTA file");
     }
@@ -59,30 +59,35 @@ sub run {
         die $self->usage_text;
     }
 
-    for my $fasta_file (@{$self->nucleotide_fasta_files})
-    {
-      
-      my $sort_fasta_before = Bio::Roary::SortFasta->new(
-         input_filename   => $fasta_file,
-		 make_multiple_of_three => 1,
-       );
-      $sort_fasta_before->sort_fasta->replace_input_with_output_file;
-	  
-	  my $prank_obj = Bio::Roary::External::Prank->new(
-	    input_filename  => $fasta_file,
-	    output_filename => $fasta_file.'.aln',
-	    job_runner      => 'Local',
-		logger          => $self->logger,
-		verbose         => $self->verbose
-	  );
-	  $prank_obj->run();
-	  
-      my $sort_fasta_after_revtrans = Bio::Roary::SortFasta->new(
-         input_filename      => $fasta_file.'.aln',
-		 remove_nnn_from_end => 1,
-       );
-      $sort_fasta_after_revtrans->sort_fasta->replace_input_with_output_file;
-      unlink($fasta_file);
+    for my $fasta_file ( @{ $self->nucleotide_fasta_files } ) {
+
+        my $sort_fasta_before = Bio::Roary::SortFasta->new(
+            input_filename         => $fasta_file,
+            make_multiple_of_three => 1,
+        );
+        $sort_fasta_before->sort_fasta->replace_input_with_output_file;
+
+        if ( $sort_fasta_before->variation_detected == 1 ) {
+
+            my $prank_obj = Bio::Roary::External::Prank->new(
+                input_filename  => $fasta_file,
+                output_filename => $fasta_file . '.aln',
+                job_runner      => 'Local',
+                logger          => $self->logger,
+                verbose         => $self->verbose
+            );
+            $prank_obj->run();
+        }
+        else {
+            move( $fasta_file, $fasta_file . '.aln' );
+        }
+
+        my $sort_fasta_after_revtrans = Bio::Roary::SortFasta->new(
+            input_filename      => $fasta_file . '.aln',
+            remove_nnn_from_end => 1,
+        );
+        $sort_fasta_after_revtrans->sort_fasta->replace_input_with_output_file;
+        unlink($fasta_file);
     }
 }
 
@@ -118,7 +123,7 @@ Bio::Roary::CommandLine::ProteinMuscleAlignmentFromNucleotides - Take in a multi
 
 =head1 VERSION
 
-version 3.1.0
+version 3.1.1
 
 =head1 SYNOPSIS
 
