@@ -1,5 +1,5 @@
 package Bio::Roary::External::Prank;
-$Bio::Roary::External::Prank::VERSION = '3.1.0';
+$Bio::Roary::External::Prank::VERSION = '3.1.1';
 # ABSTRACT: Wrapper to run prank
 
 
@@ -23,6 +23,11 @@ sub _build__memory_required_in_mb {
 sub _command_to_run {
     my ($self) = @_;
 
+    if(! -e $self->input_filename)
+	{
+		$self->logger->error( "Input file to PRANK missing: " . $self->input_filename );
+	}
+
     return join(
         ' ',
         (
@@ -71,7 +76,7 @@ Bio::Roary::External::Prank - Wrapper to run prank
 
 =head1 VERSION
 
-version 3.1.0
+version 3.1.1
 
 =head1 SYNOPSIS
 
