@@ -1,5 +1,5 @@
 package Bio::Roary::ReorderSpreadsheet;
-$Bio::Roary::ReorderSpreadsheet::VERSION = '3.1.0';
+$Bio::Roary::ReorderSpreadsheet::VERSION = '3.1.1';
 # ABSTRACT: Take in a tree file and a spreadsheet and output a spreadsheet with reordered columns
 
 
@@ -7,6 +7,7 @@ use Moose;
 use Text::CSV;
 use Bio::Roary::SampleOrder;
 use Bio::Roary::GroupStatistics;
+with 'Bio::Roary::SpreadsheetRole';
 
 has 'tree_file'   => ( is => 'ro', isa => 'Str', required => 1 );
 has 'spreadsheet' => ( is => 'ro', isa => 'Str', required => 1 );
@@ -16,13 +17,7 @@ has 'search_strategy'        => ( is => 'ro', isa => 'Str', default =>  'depth'
 has 'sortby'                 => ( is => 'ro', isa => 'Maybe[Str]');
 
 has '_sample_order'          => ( is => 'ro', isa  => 'ArrayRef', lazy    => 1, builder => '_build__sample_order' );
-has '_input_spreadsheet_fh'  => ( is => 'ro', lazy => 1,          builder => '_build__input_spreadsheet_fh' );
-has '_output_spreadsheet_fh' => ( is => 'ro', lazy => 1,          builder => '_build__output_spreadsheet_fh' );
 has '_column_mappings'       => ( is => 'ro', isa  => 'ArrayRef', lazy    => 1, builder => '_build__column_mappings' );
-has '_fixed_headers'         => ( is => 'ro', isa  => 'ArrayRef', lazy    => 1, builder => '_build__fixed_headers' );
-has '_num_fixed_headers'     => ( is => 'ro', isa  => 'Int',      lazy    => 1, builder => '_build__num_fixed_headers' );
-has '_csv_parser'            => ( is => 'ro', isa  => 'Text::CSV',lazy    => 1, builder => '_build__csv_parser' );
-has '_csv_output'            => ( is => 'ro', isa  => 'Text::CSV',lazy    => 1, builder => '_build__csv_output' );
 
 
 sub BUILD {
@@ -108,43 +103,6 @@ sub _build__column_mappings
   return \@column_mappings;
 }
 
-sub _build__num_fixed_headers
-{
-  my ($self) = @_;
-  return @{$self->_fixed_headers};
-}
-
-sub _build__fixed_headers
-{
-  my ($self) = @_;
-  my @fixed_headers = @{Bio::Roary::GroupStatistics->fixed_headers()};
-  return \@fixed_headers;
-}
-
-sub _build__csv_parser
-{
-  my ($self) = @_;
-  return Text::CSV->new( { binary => 1, always_quote => 1} );
-}
-
-sub _build__csv_output
-{
-  my ($self) = @_;
-  return Text::CSV->new( { binary => 1, always_quote => 1, eol => "\r\n"} );
-}
-
-sub _build__input_spreadsheet_fh {
-    my ($self) = @_;
-    open( my $fh, $self->spreadsheet );
-    return $fh;
-}
-
-sub _build__output_spreadsheet_fh {
-    my ($self) = @_;
-    open( my $fh, '>', $self->output_filename );
-    return $fh;
-}
-
 sub _build__sample_order {
     my ($self) = @_;
     my $obj = Bio::Roary::SampleOrder->new(
@@ -173,7 +131,7 @@ Bio::Roary::ReorderSpreadsheet - Take in a tree file and a spreadsheet and outpu
 
 =head1 VERSION
 
-version 3.1.0
+version 3.1.1
 
 =head1 SYNOPSIS
 
